@@ -38,6 +38,7 @@ class SeleniumBrowser(BrowserBase, Tagger):
     def __init__(self, driver="Firefox", leave_host=False,
                  load_images=False, form_submit_natural_click=False,
                  form_submit_wait=5, output=None, show_browser=False,
+                 form_submit_button_selector=None,
                  browser_binary=None, page_timeout=None,
                  remote_hub="http://localhost:4444/wd/hub", **kwargs):
         try:
@@ -157,6 +158,9 @@ class SeleniumBrowser(BrowserBase, Tagger):
         self.css_escapables = ".:"
         self.form_submit_natural_click = form_submit_natural_click
         self.form_submit_wait = form_submit_wait
+        # selector to locate submit button, overrides all other
+        # selection strategies
+        self.form_submit_button_selector = form_submit_button_selector
 
     def _driver_exec(self, fn, *args, **kwargs):
         """
@@ -222,8 +226,21 @@ class SeleniumBrowser(BrowserBase, Tagger):
         the page is loaded or not.
         """
         logger.debug(" - Waiting for page to load (document.readyState)...")
-        script = "return document.readyState"
-        result = driver.execute_script(script)
+        s = time.time()
+        script = """
+          var callback = arguments[arguments.length - 1];
+          setTimeout(callback(document.readyState), %s);
+          document.addEventListener('readystatechange', event => {
+            console.log(event.target.readyState);
+            if (event.target.readyState === 'interactive') {
+            }
+            else if (event.target.readyState === 'complete') {
+              callback(document.readyState);
+            }
+          });
+        """ % (5000)
+        result = self._driver_exec(self.driver.execute_async_script, script)
+        logger.debug(" - Page loaded in %s seconds" % (time.time() - s))
         return result == "complete"
 
     def _loadwait(self, fn, *args, **kwargs):
@@ -238,7 +255,7 @@ class SeleniumBrowser(BrowserBase, Tagger):
             del kwargs["check_alerts"]
 
         # get any element as a reference for staleness check
-        elem = self.driver.find_element_by_xpath("html")
+        elem = self.driver.find_element_by_xpath("//*")
 
         self._driver_exec(fn, *args, **kwargs)
         time.sleep(1)
@@ -524,23 +541,47 @@ class SeleniumBrowser(BrowserBase, Tagger):
         ac.move_to_element(elem).move_by_offset(x_off, y_off).click().perform()
 
     def _text_matches_search_button(self, text):
-        for test_text in ["submit", "search", "go"]:
+        for test_text in ["submit", "search"]:
             if test_text == text.lower():
                 return True
         return False
 
     def _find_submit_button(self, form):
+        """
+        Find a submit button by a variety of strategies:
+            1. use self.form_submit_button_selector
+            2. find a input with type 'submit'
+            3. find a link with "search" in text
+        """
         sub = None
-        submit_btns = self._driver_exec(
-            form.find_elements_by_xpath,
-            "//input[@type='submit']"
-        )
-        for el in submit_btns:
-            txt = el.get_attribute("value").lower()
-            if self._text_matches_search_button(txt):
-                sub = el
-                logger.debug(" - Form submit input button: %s" % (txt))
-                break
+        if self.form_submit_button_selector:
+            logger.debug(" - Using submit button selector: %s" % (
+                self.form_submit_button_selector
+            ))
+            sub = self._driver_exec(
+                form.find_element_by_xpath,
+                self.form_submit_button_selector
+            )
+
+        # try to find a input with type 'submit'
+        if not sub:
+            submit_btns = self._driver_exec(
+                form.find_elements_by_xpath,
+                ".//input[@type='submit']|.//button[@type='submit']"
+            )
+            for el in submit_btns:
+                if not self.element_displayed(el):
+                    continue
+                txt = self.element_text(el)
+                cls = el.get_attribute("class").lower()
+                if self._text_matches_search_button(txt):
+                    sub = el
+                    logger.debug(" - Form submit input button: %s" % (txt))
+                    break
+                if self._text_matches_search_button(cls):
+                    sub = el
+                    logger.debug(" - Form submit input button (class): %s" % (cls))
+                    break
 
         # try to find a Submit link
         # NOTE: instead of using xpath we're going to do a manual search.
@@ -550,11 +591,12 @@ class SeleniumBrowser(BrowserBase, Tagger):
         if not sub:
             try:
                 possible_subs = self._driver_exec(
-                    form.find_elements_by_xpath,
-                    "//a"
+                    form.find_elements_by_xpath, ".//a"
                 )
 
                 for el in possible_subs:
+                    if not self.element_displayed(el):
+                        continue
                     el_text = self.element_text(el)
                     if not self._text_matches_search_button(el_text):
                         continue
@@ -571,7 +613,7 @@ class SeleniumBrowser(BrowserBase, Tagger):
         Submit a form from a given tag. Assumes all inputs are filled.
         """
         logger.info("[.] Submitting form.")
-        logger.debug(" - form button tag: %s" % tag)
+        logger.debug(" - form tag: %s" % tag)
         form = self.element_by_tag(tag)
         self._driver_exec(self.scrolltoview, form)
 
